@@ -132,6 +132,9 @@ class DefiController(BaseController):
             cryptosaurio_view.display_anchor_data(
                 show_transactions=ns_parser.transactions,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 address=ns_parser.address,
             )
 
@@ -172,9 +175,12 @@ class DefiController(BaseController):
 
         if ns_parser:
             terramoney_fcd_view.display_account_staking_info(
-                export=ns_parser.export,
                 address=ns_parser.address,
                 limit=ns_parser.limit,
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -222,10 +228,13 @@ class DefiController(BaseController):
         )
         if ns_parser:
             terramoney_fcd_view.display_validators(
-                export=ns_parser.export,
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 limit=ns_parser.limit,
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -272,6 +281,9 @@ class DefiController(BaseController):
             terramoney_fcd_view.display_account_growth(
                 kind=ns_parser.kind,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 cumulative=ns_parser.cumulative,
                 limit=ns_parser.limit,
             )
@@ -302,7 +314,11 @@ class DefiController(BaseController):
 
         if ns_parser:
             terramoney_fcd_view.display_staking_ratio_history(
-                export=ns_parser.export, limit=ns_parser.limit
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+                limit=ns_parser.limit,
             )
 
     @log_start_end(log=logger)
@@ -331,7 +347,11 @@ class DefiController(BaseController):
 
         if ns_parser:
             terramoney_fcd_view.display_staking_returns_history(
-                export=ns_parser.export, limit=ns_parser.limit
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+                limit=ns_parser.limit,
             )
 
     @log_start_end(log=logger)
@@ -450,6 +470,9 @@ class DefiController(BaseController):
                 ascend=ns_parser.reverse,
                 description=ns_parser.description,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -479,7 +502,13 @@ class DefiController(BaseController):
         )
 
         if ns_parser:
-            llama_view.display_defi_tvl(limit=ns_parser.limit, export=ns_parser.export)
+            llama_view.display_defi_tvl(
+                limit=ns_parser.limit,
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+            )
 
     @log_start_end(log=logger)
     def call_newsletter(self, other_args: List[str]):
@@ -509,7 +538,11 @@ class DefiController(BaseController):
 
         if ns_parser:
             substack_view.display_newsletters(
-                limit=ns_parser.limit, export=ns_parser.export
+                limit=ns_parser.limit,
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -572,6 +605,9 @@ class DefiController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -592,7 +628,12 @@ class DefiController(BaseController):
         )
 
         if ns_parser:
-            graph_view.display_uni_stats(export=ns_parser.export)
+            graph_view.display_uni_stats(
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+            )
 
     @log_start_end(log=logger)
     def call_pairs(self, other_args: List[str]):
@@ -677,6 +718,9 @@ class DefiController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -730,6 +774,9 @@ class DefiController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -783,6 +830,9 @@ class DefiController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -880,6 +930,9 @@ class DefiController(BaseController):
                 ascend=ns_parser.reverse,
                 link=ns_parser.link,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     def call_lcsc(self, other_args: List[str]):
@@ -923,4 +976,7 @@ class DefiController(BaseController):
                 days=ns_parser.days,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
