@@ -154,6 +154,9 @@ class DiscoveryController(BaseController):
                     category=ns_parser.category,
                     limit=ns_parser.limit,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                     ascend=ns_parser.reverse,
                 )
             elif ns_parser.source == "CoinMarketCap":
@@ -162,6 +165,9 @@ class DiscoveryController(BaseController):
                     sortby=ns_parser.sortby,
                     ascend=ns_parser.reverse,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -204,6 +210,9 @@ class DiscoveryController(BaseController):
                 sortby=" ".join(ns_parser.sortby),
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -246,6 +255,9 @@ class DiscoveryController(BaseController):
                 sortby=" ".join(ns_parser.sortby),
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -288,6 +300,9 @@ class DiscoveryController(BaseController):
                 sortby=" ".join(ns_parser.sortby),
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -331,6 +346,9 @@ class DiscoveryController(BaseController):
                 sortby=" ".join(ns_parser.sortby),
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -386,6 +404,9 @@ class DiscoveryController(BaseController):
                 interval=ns_parser.interval,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 sortby=" ".join(ns_parser.sortby),
             )
 
@@ -443,6 +464,9 @@ class DiscoveryController(BaseController):
                 interval=ns_parser.interval,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 sortby=" ".join(ns_parser.sortby),
             )
 
@@ -465,6 +489,9 @@ class DiscoveryController(BaseController):
         if ns_parser:
             pycoingecko_view.display_trending(
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -542,6 +569,9 @@ class DiscoveryController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 query=" ".join(ns_parser.query),
                 category=ns_parser.category,
             )
