@@ -269,6 +269,9 @@ class DueDiligenceController(CryptoBaseController):
                     start_date=ns_parser.since.strftime("%Y-%m-%d"),
                     end_date=ns_parser.until.strftime("%Y-%m-%d"),
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
             else:
@@ -302,7 +305,7 @@ class DueDiligenceController(CryptoBaseController):
 
         if ns_parser:
             pair = f"{coin}-{ns_parser.vs.upper()}"
-            coinbase_view.display_stats(pair, ns_parser.export)
+            coinbase_view.display_stats(pair, ns_parser.export, ns_parser.sheet_name)
 
     @log_start_end(log=logger)
     def call_active(self, other_args: List[str]):
@@ -357,6 +360,9 @@ class DueDiligenceController(CryptoBaseController):
                     start_date=ns_parser.since.strftime("%Y-%m-%d"),
                     end_date=ns_parser.until.strftime("%Y-%m-%d"),
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print(f"[red]{self.symbol} not supported on Glassnode.[/red]")
@@ -419,6 +425,9 @@ class DueDiligenceController(CryptoBaseController):
                     start_date=ns_parser.since.strftime("%Y-%m-%d"),
                     end_date=ns_parser.until.strftime("%Y-%m-%d"),
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print(f"[red]{self.symbol} not supported on Glassnode.[/red]")
@@ -491,6 +500,9 @@ class DueDiligenceController(CryptoBaseController):
                     end_date=ns_parser.until.strftime("%Y-%m-%d"),
                     percentage=ns_parser.percentage,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print(f"[red]{self.symbol} not supported on Glassnode.[/red]")
@@ -498,7 +510,7 @@ class DueDiligenceController(CryptoBaseController):
     @log_start_end(log=logger)
     def call_oi(self, other_args):
         """Process oi command"""
-        assert isinstance(self.symbol, str)
+        assert isinstance(self.symbol, str)  # noqa: S101
         parser = argparse.ArgumentParser(
             add_help=False,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
@@ -528,12 +540,15 @@ class DueDiligenceController(CryptoBaseController):
                 symbol=self.symbol.upper(),
                 interval=ns_parser.interval,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
     def call_liquidations(self, other_args):
         """Process liquidations command"""
-        assert isinstance(self.symbol, str)
+        assert isinstance(self.symbol, str)  # noqa: S101
         parser = argparse.ArgumentParser(
             add_help=False,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
@@ -552,12 +567,15 @@ class DueDiligenceController(CryptoBaseController):
             coinglass_view.display_liquidations(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
     def call_fundrate(self, other_args):
         """Process fundrate command"""
-        assert isinstance(self.symbol, str)
+        assert isinstance(self.symbol, str)  # noqa: S101
         parser = argparse.ArgumentParser(
             add_help=False,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
@@ -576,6 +594,9 @@ class DueDiligenceController(CryptoBaseController):
             coinglass_view.display_funding_rate(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -600,6 +621,9 @@ class DueDiligenceController(CryptoBaseController):
                 pycoingecko_view.display_info(
                     symbol=self.symbol,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -619,7 +643,13 @@ class DueDiligenceController(CryptoBaseController):
         if ns_parser:
             cg_id = check_cg_id(self.symbol)
             if cg_id:
-                pycoingecko_view.display_market(cg_id, ns_parser.export)
+                pycoingecko_view.display_market(
+                    cg_id,
+                    ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
 
     @log_start_end(log=logger)
     def call_web(self, other_args):
@@ -641,6 +671,9 @@ class DueDiligenceController(CryptoBaseController):
                 pycoingecko_view.display_web(
                     self.symbol,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -660,7 +693,13 @@ class DueDiligenceController(CryptoBaseController):
         if ns_parser:
             cg_id = check_cg_id(self.symbol)
             if cg_id:
-                pycoingecko_view.display_social(cg_id, export=ns_parser.export)
+                pycoingecko_view.display_social(
+                    cg_id,
+                    export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
 
     @log_start_end(log=logger)
     def call_dev(self, other_args):
@@ -682,7 +721,13 @@ class DueDiligenceController(CryptoBaseController):
         if ns_parser:
             cg_id = check_cg_id(self.symbol)
             if cg_id:
-                pycoingecko_view.display_dev(cg_id, ns_parser.export)
+                pycoingecko_view.display_dev(
+                    cg_id,
+                    ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
 
     @log_start_end(log=logger)
     def call_ath(self, other_args):
@@ -709,7 +754,14 @@ class DueDiligenceController(CryptoBaseController):
         if ns_parser:
             cg_id = check_cg_id(self.symbol)
             if cg_id:
-                pycoingecko_view.display_ath(cg_id, ns_parser.vs, ns_parser.export)
+                pycoingecko_view.display_ath(
+                    cg_id,
+                    ns_parser.vs,
+                    ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
 
     @log_start_end(log=logger)
     def call_atl(self, other_args):
@@ -735,7 +787,14 @@ class DueDiligenceController(CryptoBaseController):
         if ns_parser:
             cg_id = check_cg_id(self.symbol)
             if cg_id:
-                pycoingecko_view.display_atl(cg_id, ns_parser.vs, ns_parser.export)
+                pycoingecko_view.display_atl(
+                    cg_id,
+                    ns_parser.vs,
+                    ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
 
     @log_start_end(log=logger)
     def call_score(self, other_args):
@@ -758,7 +817,13 @@ class DueDiligenceController(CryptoBaseController):
         if ns_parser:
             cg_id = check_cg_id(self.symbol)
             if cg_id:
-                pycoingecko_view.display_score(cg_id, ns_parser.export)
+                pycoingecko_view.display_score(
+                    cg_id,
+                    ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
 
     @log_start_end(log=logger)
     def call_bc(self, other_args):
@@ -779,7 +844,13 @@ class DueDiligenceController(CryptoBaseController):
         if ns_parser:
             cg_id = check_cg_id(self.symbol)
             if cg_id:
-                pycoingecko_view.display_bc(cg_id, ns_parser.export)
+                pycoingecko_view.display_bc(
+                    cg_id,
+                    ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
+                )
 
     @log_start_end(log=logger)
     def call_ob(self, other_args):
@@ -824,6 +895,9 @@ class DueDiligenceController(CryptoBaseController):
                 symbol=self.symbol,
                 to_symbol=ns_parser.vs,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -869,6 +943,9 @@ class DueDiligenceController(CryptoBaseController):
                 symbol=self.symbol,
                 to_symbol=ns_parser.vs,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 limit=ns_parser.limit,
             )
 
@@ -904,7 +981,12 @@ class DueDiligenceController(CryptoBaseController):
 
         if ns_parser:
             binance_view.display_balance(
-                from_symbol=coin, to_symbol=ns_parser.vs, export=ns_parser.export
+                from_symbol=coin,
+                to_symbol=ns_parser.vs,
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1031,6 +1113,9 @@ class DueDiligenceController(CryptoBaseController):
                     ascend=ns_parser.reverse,
                     links=ns_parser.urls,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -1087,6 +1172,9 @@ class DueDiligenceController(CryptoBaseController):
                     sortby=ns_parser.sortby,
                     ascend=ns_parser.reverse,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -1154,6 +1242,9 @@ class DueDiligenceController(CryptoBaseController):
                     ascend=ns_parser.reverse,
                     links=ns_parser.urls,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -1211,6 +1302,9 @@ class DueDiligenceController(CryptoBaseController):
                     sortby=ns_parser.sortby,
                     ascend=ns_parser.reverse,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -1266,6 +1360,9 @@ class DueDiligenceController(CryptoBaseController):
                 start_date=ns_parser.start,
                 end_date=ns_parser.end,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1289,6 +1386,9 @@ class DueDiligenceController(CryptoBaseController):
             messari_view.display_links(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1391,6 +1491,9 @@ class DueDiligenceController(CryptoBaseController):
                 symbol=self.symbol.upper(),
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1416,6 +1519,9 @@ class DueDiligenceController(CryptoBaseController):
                 messari_view.display_tokenomics(
                     symbol=self.symbol.upper(),
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -1440,6 +1546,9 @@ class DueDiligenceController(CryptoBaseController):
             messari_view.display_project_info(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1464,6 +1573,9 @@ class DueDiligenceController(CryptoBaseController):
             messari_view.display_team(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1488,6 +1600,9 @@ class DueDiligenceController(CryptoBaseController):
             messari_view.display_investors(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1512,6 +1627,9 @@ class DueDiligenceController(CryptoBaseController):
             messari_view.display_fundraising(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1536,6 +1654,9 @@ class DueDiligenceController(CryptoBaseController):
             messari_view.display_governance(
                 symbol=self.symbol.upper(),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1644,6 +1765,9 @@ class DueDiligenceController(CryptoBaseController):
                     start_date=ns_parser.start,
                     end_date=ns_parser.end,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -1737,6 +1861,9 @@ class DueDiligenceController(CryptoBaseController):
                 source=None,
                 symbol=self.symbol,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 ascend=ns_parser.reverse,
                 post_kind=ns_parser.kind,
                 filter_=ns_parser.filter,
@@ -1780,6 +1907,9 @@ class DueDiligenceController(CryptoBaseController):
                 metric=ns_parser.metric,
                 project=ns_parser.project,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1811,4 +1941,7 @@ class DueDiligenceController(CryptoBaseController):
                 tokenterminal_view.display_description(
                     project=ns_parser.project,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
