@@ -8,7 +8,6 @@ from typing import Any, Optional, Tuple
 from datetime import datetime, timedelta
 import re
 import pandas as pd
-import requests
 
 from openbb_terminal import config_terminal as cfg
 from openbb_terminal.cryptocurrency.dataframe_helpers import (
@@ -19,7 +18,7 @@ from openbb_terminal.cryptocurrency.due_diligence.pycoingecko_model import (
     get_coin_tokenomics,
 )
 from openbb_terminal.decorators import check_api_key, log_start_end
-from openbb_terminal.helper_funcs import lambda_long_number_format
+from openbb_terminal.helper_funcs import lambda_long_number_format, request
 from openbb_terminal.rich_config import console
 
 # pylint: disable=unsupported-assignment-operation
@@ -45,7 +44,7 @@ def get_available_timeseries(only_free: bool = True) -> pd.DataFrame:
     pd.DataFrame
         available timeseries
     """
-    r = requests.get("https://data.messari.io/api/v1/assets/metrics")
+    r = request("https://data.messari.io/api/v1/assets/metrics")
     if r.status_code == 200:
         data = r.json()
         metrics = data["data"]["metrics"]
@@ -102,6 +101,11 @@ def get_marketcap_dominance(
     -------
     pd.DataFrame
         market dominance percentage over time
+
+    Examples
+    --------
+    >>> from openbb_terminal.sdk import openbb
+    >>> mcapdom_df = openbb.crypto.dd.mcapdom(symbol="BTC")
     """
 
     if start_date is None:
@@ -110,13 +114,14 @@ def get_marketcap_dominance(
     if end_date is None:
         end_date = datetime.now().strftime("%Y-%m-%d")
 
-    df, _ = get_messari_timeseries(
+    messari_timeseries = get_messari_timeseries(
         symbol=symbol,
         end_date=end_date,
         start_date=start_date,
         interval=interval,
         timeseries_id="mcap.dom",
     )
+    df, _ = messari_timeseries if messari_timeseries else (pd.DataFrame(), "")
     return df
 
 
@@ -168,7 +173,7 @@ def get_messari_timeseries(
         "interval": interval,
     }
 
-    r = requests.get(url, params=parameters, headers=headers)
+    r = request(url, params=parameters, headers=headers)
 
     df = pd.DataFrame()
     title = ""
@@ -216,7 +221,7 @@ def get_links(symbol: str) -> pd.DataFrame:
 
     params = {"fields": "profile/general/overview/official_links"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
 
@@ -257,7 +262,7 @@ def get_roadmap(symbol: str, ascend: bool = True) -> pd.DataFrame:
 
     params = {"fields": "profile/general/roadmap"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
 
@@ -305,7 +310,7 @@ def get_tokenomics(symbol: str, coingecko_id: str) -> Tuple[pd.DataFrame, pd.Dat
 
     params = {"fields": "profile/economics/consensus_and_emission"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
     circ_df = pd.DataFrame()
@@ -377,7 +382,7 @@ def get_project_product_info(
 
     params = {"fields": "profile/general/overview/project_details,profile/technology"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
     if r.status_code == 200:
@@ -439,7 +444,7 @@ def get_team(symbol: str) -> Tuple[pd.DataFrame, pd.DataFrame]:
 
     params = {"fields": "profile/contributors"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
     if r.status_code == 200:
@@ -514,7 +519,7 @@ def get_investors(symbol: str) -> Tuple[pd.DataFrame, pd.DataFrame]:
 
     params = {"fields": "profile/investors"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
     if r.status_code == 200:
@@ -587,7 +592,7 @@ def get_governance(symbol: str) -> Tuple[str, pd.DataFrame]:
 
     params = {"fields": "profile/governance"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
     if r.status_code == 200:
@@ -653,6 +658,11 @@ def get_fundraising(
         Sales rounds,
         Treasury Accounts,
         Metric Value launch details
+
+    Examples
+    --------
+    >>> from openbb_terminal.sdk import openbb
+    >>> fundraise = openbb.crypto.dd.fr(symbol="BTC")
     """
 
     url = base_url2 + f"assets/{symbol}/profile"
@@ -661,7 +671,7 @@ def get_fundraising(
 
     params = {"fields": "profile/economics/launch"}
 
-    r = requests.get(url, headers=headers, params=params)
+    r = request(url, headers=headers, params=params)
 
     df = pd.DataFrame()
     if r.status_code == 200:
