@@ -84,6 +84,7 @@ class OnchainController(BaseController):
         "baas",
         "btccp",
         "btcct",
+        "btcblockdata",
         "dt",
         "ds",
         "tvl",
@@ -115,6 +116,7 @@ class OnchainController(BaseController):
         mt.add_cmd("hr")
         mt.add_cmd("btccp")
         mt.add_cmd("btcct")
+        mt.add_cmd("btcblockdata")
         mt.add_cmd("gwei")
         mt.add_cmd("whales")
         mt.add_cmd("lt")
@@ -204,6 +206,9 @@ class OnchainController(BaseController):
                 interval=ns_parser.interval,
                 symbol=ns_parser.symbol,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -242,6 +247,9 @@ class OnchainController(BaseController):
                 limit=ns_parser.limit,
                 platform=ns_parser.platform,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -264,6 +272,9 @@ class OnchainController(BaseController):
         if ns_parser:
             shroom_view.display_daily_transactions(
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -305,6 +316,9 @@ class OnchainController(BaseController):
                 start_date=ns_parser.since.strftime("%Y-%m-%d"),
                 end_date=ns_parser.until.strftime("%Y-%m-%d"),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -346,6 +360,9 @@ class OnchainController(BaseController):
                 start_date=ns_parser.since.strftime("%Y-%m-%d"),
                 end_date=ns_parser.until.strftime("%Y-%m-%d"),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -413,6 +430,9 @@ class OnchainController(BaseController):
                 start_date=ns_parser.since.strftime("%Y-%m-%d"),
                 end_date=ns_parser.until.strftime("%Y-%m-%d"),
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -433,7 +453,12 @@ class OnchainController(BaseController):
         )
 
         if ns_parser:
-            ethgasstation_view.display_gwei_fees(export=ns_parser.export)
+            ethgasstation_view.display_gwei_fees(
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+            )
 
     @log_start_end(log=logger)
     def call_whales(self, other_args: List[str]):
@@ -504,6 +529,9 @@ class OnchainController(BaseController):
                 ascend=ns_parser.reverse,
                 show_address=ns_parser.address,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -634,6 +662,9 @@ class OnchainController(BaseController):
                     ascend=ns_parser.reverse,
                     address=self.address,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("You need to set an ethereum address\n")
@@ -691,6 +722,9 @@ class OnchainController(BaseController):
                     ascend=ns_parser.reverse,
                     address=self.address,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("You need to set an ethereum address\n")
@@ -747,6 +781,9 @@ class OnchainController(BaseController):
                     ascend=ns_parser.reverse,
                     address=self.address,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("You need to set an ethereum address\n")
@@ -802,6 +839,9 @@ class OnchainController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -835,6 +875,9 @@ class OnchainController(BaseController):
                     social=ns_parser.social,
                     address=self.address,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("You need to set an ethereum address\n")
@@ -901,6 +944,9 @@ class OnchainController(BaseController):
                     ascend=ns_parser.reverse,
                     address=self.address,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("You need to set an ethereum address\n")
@@ -928,6 +974,9 @@ class OnchainController(BaseController):
                 ethplorer_view.display_tx_info(
                     tx_hash=self.address,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("You need to set an ethereum address\n")
@@ -984,6 +1033,9 @@ class OnchainController(BaseController):
                     ascend=ns_parser.reverse,
                     address=self.address,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("You need to set an ethereum address\n")
@@ -1069,6 +1121,9 @@ class OnchainController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1146,6 +1201,9 @@ class OnchainController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1221,6 +1279,9 @@ class OnchainController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1292,6 +1353,9 @@ class OnchainController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1402,6 +1466,9 @@ class OnchainController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1479,6 +1546,9 @@ class OnchainController(BaseController):
                         sortby=ns_parser.sortby,
                         ascend=ns_parser.reverse,
                         export=ns_parser.export,
+                        sheet_name=" ".join(ns_parser.sheet_name)
+                        if ns_parser.sheet_name
+                        else None,
                     )
 
                 else:
@@ -1503,6 +1573,9 @@ class OnchainController(BaseController):
                                     sortby=ns_parser.sortby,
                                     ascend=ns_parser.reverse,
                                     export=ns_parser.export,
+                                    sheet_name=" ".join(ns_parser.sheet_name)
+                                    if ns_parser.sheet_name
+                                    else None,
                                 )
                         except Exception:
                             similar_cmd = difflib.get_close_matches(
@@ -1516,3 +1589,40 @@ class OnchainController(BaseController):
 
             else:
                 console.print("You didn't provide coin symbol.\n")
+
+    @log_start_end(log=logger)
+    def call_btcblockdata(self, other_args: List[str]):
+        """Process btcblockdata command"""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="btcblockdata",
+            description="""
+                          Display block data from Blockchain.com,
+                          [Source: https://api.blockchain.info/]
+                      """,
+        )
+
+        if other_args and "-" not in other_args[0]:
+            other_args.insert(0, "--blockhash")
+
+        parser.add_argument(
+            "--blockhash",
+            action="store",
+            help="Flag for block hash of block.",
+            dest="blockhash",
+            default=False,
+        )
+
+        ns_parser = self.parse_known_args_and_warn(
+            parser, other_args, EXPORT_ONLY_RAW_DATA_ALLOWED
+        )
+
+        if ns_parser:
+            blockchain_view.display_btc_single_block(
+                blockhash=ns_parser.blockhash,
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+            )
