@@ -22,6 +22,7 @@ def display_trading_pairs(
     sortby: str = "quote_increment",
     ascend: bool = True,
     export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Displays a list of available currency pairs for trading. [Source: Coinbase]
 
@@ -51,4 +52,5 @@ def display_trading_pairs(
         os.path.dirname(os.path.abspath(__file__)),
         "cbpairs",
         df,
+        sheet_name,
     )
