@@ -37,6 +37,7 @@ def display_crypto_heatmap(
     category: str = "",
     limit: int = 15,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ) -> None:
     """Shows cryptocurrencies heatmap [Source: CoinGecko]
@@ -47,6 +48,8 @@ def display_crypto_heatmap(
         Category (e.g., stablecoins). Empty for no category (default: )
     limit: int
         Number of top cryptocurrencies to display
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export dataframe data to csv,json,xlsx
     external_axes : Optional[List[plt.Axes]], optional
@@ -128,12 +131,17 @@ def display_crypto_heatmap(
             os.path.dirname(os.path.abspath(__file__)),
             "hm",
             df,
+            sheet_name,
         )
 
 
 @log_start_end(log=logger)
 def display_holdings_overview(
-    symbol: str, show_bar: bool = False, export: str = "", limit: int = 15
+    symbol: str,
+    show_bar: bool = False,
+    export: str = "",
+    sheet_name: str = None,
+    limit: int = 15,
 ) -> None:
     """Shows overview of public companies that holds ethereum or bitcoin. [Source: CoinGecko]
 
@@ -143,6 +151,8 @@ def display_holdings_overview(
         Cryptocurrency: ethereum or bitcoin
     show_bar : bool
         Whether to show a bar graph for the data
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export dataframe data to csv,json,xlsx
     limit: int
@@ -193,12 +203,17 @@ def display_holdings_overview(
             os.path.dirname(os.path.abspath(__file__)),
             "cghold",
             df,
+            sheet_name,
         )
 
 
 @log_start_end(log=logger)
 def display_exchange_rates(
-    sortby: str = "Name", ascend: bool = False, limit: int = 15, export: str = ""
+    sortby: str = "Name",
+    ascend: bool = False,
+    limit: int = 15,
+    export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Shows  list of crypto, fiats, commodity exchange rates. [Source: CoinGecko]
 
@@ -229,13 +244,16 @@ def display_exchange_rates(
             os.path.dirname(os.path.abspath(__file__)),
             "exrates",
             df,
+            sheet_name,
         )
     else:
         console.print("Unable to retrieve data from CoinGecko.")
 
 
 @log_start_end(log=logger)
-def display_global_market_info(pie: bool = False, export: str = "") -> None:
+def display_global_market_info(
+    pie: bool = False, export: str = "", sheet_name: str = None
+) -> None:
     """Shows global statistics about crypto. [Source: CoinGecko]
         - market cap change
         - number of markets
@@ -292,13 +310,14 @@ def display_global_market_info(pie: bool = False, export: str = "") -> None:
             os.path.dirname(os.path.abspath(__file__)),
             "cgglobal",
             df,
+            sheet_name,
         )
     else:
         console.print("Unable to retrieve data from CoinGecko.")
 
 
 @log_start_end(log=logger)
-def display_global_defi_info(export: str = "") -> None:
+def display_global_defi_info(export: str = "", sheet_name: str = None) -> None:
     """Shows global statistics about Decentralized Finances. [Source: CoinGecko]
 
     Parameters
@@ -322,6 +341,7 @@ def display_global_defi_info(export: str = "") -> None:
             os.path.dirname(os.path.abspath(__file__)),
             "defi",
             df,
+            sheet_name,
         )
     else:
         console.print("Unable to retrieve data from CoinGecko.")
@@ -331,6 +351,7 @@ def display_global_defi_info(export: str = "") -> None:
 def display_stablecoins(
     limit: int = 15,
     export: str = "",
+    sheet_name: str = None,
     sortby: str = "Market_Cap_[$]",
     ascend: bool = False,
     pie: bool = True,
@@ -361,7 +382,6 @@ def display_stablecoins(
     df = gecko.get_stable_coins(limit, sortby=sortby, ascend=ascend)
 
     if not df.empty:
-
         total_market_cap = int(df["Market_Cap_[$]"].sum())
         df.columns = df.columns.str.replace("_", " ")
 
@@ -407,6 +427,7 @@ def display_stablecoins(
             os.path.dirname(os.path.abspath(__file__)),
             "cgstables",
             df,
+            sheet_name,
         )
     else:
         console.print("\nUnable to retrieve data from CoinGecko.\n")
@@ -417,6 +438,7 @@ def display_categories(
     sortby: str = "market_cap_desc",
     limit: int = 15,
     export: str = "",
+    sheet_name: str = None,
     pie: bool = False,
 ) -> None:
     """Shows top cryptocurrency categories by market capitalization
@@ -429,6 +451,8 @@ def display_categories(
         Key by which to sort data
     limit: int
         Number of records to display
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export dataframe data to csv,json,xlsx file
     pie: bool
@@ -473,6 +497,7 @@ def display_categories(
             os.path.dirname(os.path.abspath(__file__)),
             "cgcategories",
             df_data,
+            sheet_name,
         )
     else:
         console.print("\nUnable to retrieve data from CoinGecko.\n")
@@ -485,6 +510,7 @@ def display_exchanges(
     limit: int = 15,
     links: bool = False,
     export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Shows list of top exchanges from CoinGecko. [Source: CoinGecko]
 
@@ -505,7 +531,6 @@ def display_exchanges(
     df = gecko.get_exchanges(sortby, ascend)
 
     if not df.empty:
-
         if links is True:
             df = df[["Rank", "Name", "Url"]]
         else:
@@ -523,6 +548,7 @@ def display_exchanges(
             os.path.dirname(os.path.abspath(__file__)),
             "exchanges",
             df,
+            sheet_name,
         )
     else:
         console.print("Unable to retrieve data from CoinGecko.")
@@ -530,7 +556,11 @@ def display_exchanges(
 
 @log_start_end(log=logger)
 def display_platforms(
-    sortby: str = "Name", ascend: bool = True, limit: int = 15, export: str = ""
+    sortby: str = "Name",
+    ascend: bool = True,
+    limit: int = 15,
+    export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Shows list of financial platforms. [Source: CoinGecko]
 
@@ -561,6 +591,7 @@ def display_platforms(
             os.path.dirname(os.path.abspath(__file__)),
             "platforms",
             df,
+            sheet_name,
         )
     else:
         console.print("\nUnable to retrieve data from CoinGecko.\n")
@@ -568,7 +599,11 @@ def display_platforms(
 
 @log_start_end(log=logger)
 def display_products(
-    sortby: str = "Platform", ascend: bool = False, limit: int = 15, export: str = ""
+    sortby: str = "Platform",
+    ascend: bool = False,
+    limit: int = 15,
+    export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Shows list of financial products. [Source: CoinGecko]
 
@@ -599,6 +634,7 @@ def display_products(
             os.path.dirname(os.path.abspath(__file__)),
             "products",
             df,
+            sheet_name,
         )
     else:
         console.print("Unable to retrieve data from CoinGecko.")
@@ -606,7 +642,11 @@ def display_products(
 
 @log_start_end(log=logger)
 def display_indexes(
-    sortby: str = "Name", ascend: bool = True, limit: int = 15, export: str = ""
+    sortby: str = "Name",
+    ascend: bool = True,
+    limit: int = 15,
+    export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Shows list of crypto indexes. [Source: CoinGecko]
 
@@ -636,6 +676,7 @@ def display_indexes(
             os.path.dirname(os.path.abspath(__file__)),
             "indexes",
             df,
+            sheet_name,
         )
     else:
         console.print("Unable to retrieve data from CoinGecko.")
@@ -643,7 +684,11 @@ def display_indexes(
 
 @log_start_end(log=logger)
 def display_derivatives(
-    sortby: str = "Rank", ascend: bool = False, limit: int = 15, export: str = ""
+    sortby: str = "Rank",
+    ascend: bool = False,
+    limit: int = 15,
+    export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Shows  list of crypto derivatives. [Source: CoinGecko]
 
@@ -662,7 +707,6 @@ def display_derivatives(
     df = gecko.get_derivatives(sortby=sortby, ascend=ascend)
 
     if not df.empty:
-
         print_rich_table(
             df.head(limit),
             headers=list(df.columns),
@@ -675,6 +719,7 @@ def display_derivatives(
             os.path.dirname(os.path.abspath(__file__)),
             "derivatives",
             df,
+            sheet_name,
         )
     else:
         console.print("Unable to retrieve data from CoinGecko.")
