@@ -52,8 +52,7 @@ class WordCompleter(Completer):
         match_middle: bool = False,
         pattern: Optional[Pattern[str]] = None,
     ) -> None:
-
-        assert not (WORD and sentence)
+        assert not (WORD and sentence)  # noqa: S101
 
         self.words = words
         self.ignore_case = ignore_case
@@ -131,7 +130,6 @@ class NestedCompleter(Completer):
     def __init__(
         self, options: Dict[str, Optional[Completer]], ignore_case: bool = True
     ) -> None:
-
         self.flags_processed: List = list()
         self.original_options = options
         self.options = options
@@ -177,7 +175,7 @@ class NestedCompleter(Completer):
             elif isinstance(key, str) and isinstance(value, str):
                 options[key] = options[value]
             else:
-                assert value is None
+                assert value is None  # noqa: S101
                 options[key] = None
 
         for items in cls.complementary:
