@@ -285,21 +285,19 @@ class EconometricsController(BaseController):
 
     def update_loaded(self):
         self.list_dataset_cols = []
+        self.loaded_dataset_cols = "\n"
+
         if not self.files:
-            self.loaded_dataset_cols = "\n"
             self.list_dataset_cols.append("")
             return
 
         maxfile = max(len(file) for file in self.files)
-        self.loaded_dataset_cols = "\n"
-        for dataset, data in self.datasets.items():
-            max_files = (maxfile - len(dataset)) * " "
-            self.loaded_dataset_cols += (
-                f"\t{dataset} {max_files}: {', '.join(data.columns)}\n"
-            )
 
-            for col in data.columns:
-                self.list_dataset_cols.append(f"{dataset}.{col}")
+        for dataset, data in self.datasets.items():
+            dataset_columns = ", ".join(data.columns)
+            dataset_name = f"{dataset} {(maxfile - len(dataset)) * ' '}:"
+            self.loaded_dataset_cols += f"\t{dataset_name} {dataset_columns}\n"
+            self.list_dataset_cols.extend([f"{dataset}.{col}" for col in data.columns])
 
     @log_start_end(log=logger)
     def call_load(self, other_args: List[str]):
@@ -599,6 +597,7 @@ class EconometricsController(BaseController):
                     os.path.dirname(os.path.abspath(__file__)),
                     f"{ns_parser.name}_show",
                     df.head(ns_parser.limit),
+                    ns_parser.sheet_name,
                 )
 
     @log_start_end(log=logger)
@@ -642,6 +641,7 @@ class EconometricsController(BaseController):
                     os.path.dirname(os.path.abspath(__file__)),
                     f"{dataset}_{col}_desc",
                     df,
+                    ns_parser.sheet_name,
                 )
             else:
                 df = self.datasets[ns_parser.name]
@@ -659,6 +659,7 @@ class EconometricsController(BaseController):
                         os.path.dirname(os.path.abspath(__file__)),
                         f"{ns_parser.name}_desc",
                         df,
+                        ns_parser.sheet_name,
                     )
                 else:
                     console.print("Empty dataset")
@@ -1526,7 +1527,13 @@ class EconometricsController(BaseController):
             parser, other_args, EXPORT_ONLY_RAW_DATA_ALLOWED
         )
         if ns_parser:
-            regression_model.get_comparison(self.regression, ns_parser.export)
+            regression_model.get_comparison(
+                self.regression,
+                ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+            )
             console.print()
 
     @log_start_end(log=logger)
@@ -1675,7 +1682,6 @@ class EconometricsController(BaseController):
         )
 
         if ns_parser and ns_parser.ts:
-
             datasetcol_y, datasetcol_x = ns_parser.ts.split(",")
 
             dataset_y, column_y = datasetcol_y.split(".")
@@ -1730,7 +1736,6 @@ class EconometricsController(BaseController):
         )
 
         if ns_parser:
-
             if ns_parser.ts:
                 # We are going to pass through a variable number of series, so datasets will be a list of series
                 if len(ns_parser.ts) > 1:
@@ -1750,6 +1755,9 @@ class EconometricsController(BaseController):
                         significant=ns_parser.significant,
                         plot=ns_parser.plot,
                         export=ns_parser.export,
+                        sheet_name=" ".join(ns_parser.sheet_name)
+                        if ns_parser.sheet_name
+                        else None,
                     )
 
                 else:
