@@ -30,7 +30,6 @@ from openbb_terminal.economy import (
     fred_model,
     yfinance_model,
     yfinance_view,
-    investingcom_model,
     plot_view,
     commodity_view,
 )
@@ -196,6 +195,10 @@ class EconomyController(BaseController):
                 c: {} for c in nasdaq_model.get_country_codes()["Code"].values
             }
             choices["bigmac"]["-c"] = "--countries"
+            choices["events"]["--countries"] = {
+                c: {} for c in nasdaq_model.get_country_names()
+            }
+            choices["events"]["-c"] = "--countries"
 
             self.choices = choices
             self.completer = NestedCompleter.from_nested_dict(choices)
@@ -309,22 +312,37 @@ class EconomyController(BaseController):
             if not ns_parser.type:
                 wsj_view.display_overview(
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             elif ns_parser.type == "indices":
                 wsj_view.display_indices(
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             if ns_parser.type == "usbonds":
                 wsj_view.display_usbonds(
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             if ns_parser.type == "glbonds":
                 wsj_view.display_glbonds(
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             if ns_parser.type == "currencies":
                 wsj_view.display_currencies(
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -381,6 +399,9 @@ class EconomyController(BaseController):
                         sortby=ns_parser.sortby,
                         ascend=ns_parser.reverse,
                         export=ns_parser.export,
+                        sheet_name=" ".join(ns_parser.sheet_name)
+                        if ns_parser.sheet_name
+                        else None,
                     )
                 else:
                     console.print(
@@ -391,6 +412,9 @@ class EconomyController(BaseController):
                     console.print("[red]Commodity flag valid with Finviz only.[/red]")
                 wsj_view.display_futures(
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -476,6 +500,9 @@ class EconomyController(BaseController):
                     country_codes=ns_parser.countries,
                     raw=ns_parser.raw,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
     @log_start_end(log=logger)
@@ -541,7 +568,7 @@ class EconomyController(BaseController):
             dest="currency",
             help="Convert the currency of the chosen country to a specified currency. To find the "
             "currency symbols use '--show countries'",
-            choices=econdb_model.COUNTRY_CURRENCIES,
+            choices=econdb_model.COUNTRY_CURRENCIES.values(),
             default=False,
         )
         if other_args and "-" not in other_args[0][0]:
@@ -575,7 +602,6 @@ class EconomyController(BaseController):
                 return self.queue
 
             if ns_parser.parameters and ns_parser.countries:
-
                 # Store data
                 (df, units, _) = econdb_model.get_aggregated_macro_data(
                     parameters=parameters,
@@ -592,7 +618,13 @@ class EconomyController(BaseController):
                     if ns_parser.transform:
                         df.columns = [df.columns[0] + f"_{ns_parser.transform}"]
 
-                    self.DATASETS["macro"] = pd.concat([self.DATASETS["macro"], df])
+                    for column in df.columns:
+                        if column in self.DATASETS["macro"].columns:
+                            self.DATASETS["macro"].drop(column, axis=1, inplace=True)
+
+                    self.DATASETS["macro"] = pd.concat(
+                        [self.DATASETS["macro"], df], axis=1
+                    )
 
                     # update units dict
                     for country, data in units.items():
@@ -616,6 +648,9 @@ class EconomyController(BaseController):
                         symbol=ns_parser.currency,
                         raw=ns_parser.raw,
                         export=ns_parser.export,
+                        sheet_name=" ".join(ns_parser.sheet_name)
+                        if ns_parser.sheet_name
+                        else None,
                     )
 
                     self.update_runtime_choices()
@@ -715,11 +750,13 @@ class EconomyController(BaseController):
                     limit=ns_parser.limit,
                     raw=ns_parser.raw,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                     get_data=True,
                 )
 
                 if not df.empty:
-
                     for series_id, data in detail.items():
                         self.FRED_TITLES[
                             series_id
@@ -867,6 +904,9 @@ class EconomyController(BaseController):
                                 column=ns_parser.column,
                                 raw=ns_parser.raw,
                                 export=ns_parser.export,
+                                sheet_name=" ".join(ns_parser.sheet_name)
+                                if ns_parser.sheet_name
+                                else None,
                                 returns=ns_parser.returns,
                             )
 
@@ -961,20 +1001,25 @@ class EconomyController(BaseController):
                 )
 
                 if not df.empty:
-                    self.DATASETS["treasury"] = pd.concat(
-                        [
-                            self.DATASETS["treasury"],
-                            df,
-                        ]
-                    )
-
                     cols = []
-                    for column in self.DATASETS["treasury"].columns:
+                    for column in df.columns:
                         if isinstance(column, tuple):
                             cols.append("_".join(column))
                         else:
                             cols.append(column)
-                    self.DATASETS["treasury"].columns = cols
+                    df.columns = cols
+
+                    for column in df.columns:
+                        if column in self.DATASETS["treasury"].columns:
+                            self.DATASETS["treasury"].drop(column, axis=1, inplace=True)
+
+                    self.DATASETS["treasury"] = pd.concat(
+                        [
+                            self.DATASETS["treasury"],
+                            df,
+                        ],
+                        axis=1,
+                    )
 
                     self.stored_datasets = (
                         economy_helpers.update_stored_datasets_string(self.DATASETS)
@@ -988,6 +1033,9 @@ class EconomyController(BaseController):
                         end_date=ns_parser.end_date,
                         raw=ns_parser.raw,
                         export=ns_parser.export,
+                        sheet_name=" ".join(ns_parser.sheet_name)
+                        if ns_parser.sheet_name
+                        else None,
                     )
 
                     self.update_runtime_choices()
@@ -1019,11 +1067,13 @@ class EconomyController(BaseController):
             raw=True,
         )
         if ns_parser:
-
             fred_view.display_yield_curve(
                 date=ns_parser.date.strftime("%Y-%m-%d") if ns_parser.date else "",
                 raw=ns_parser.raw,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
             # TODO: Add `Investing` to sources again when `investpy` is fixed
@@ -1039,16 +1089,21 @@ class EconomyController(BaseController):
         )
         parser.add_argument(
             "-c",
-            "--country",
+            "--countries",
             action="store",
-            dest="country",
-            choices=[
-                x.replace(" ", "_") for x in investingcom_model.CALENDAR_COUNTRIES
-            ],
+            dest="countries",
             type=str,
             default="",
             help="Display calendar for specific country.",
         )
+        parser.add_argument(
+            "-n",
+            "--names",
+            help="Flag to show all available country names",
+            dest="names",
+            action="store_true",
+            default=False,
+        )
         parser.add_argument(
             "-s",
             "--start",
@@ -1073,22 +1128,6 @@ class EconomyController(BaseController):
             help="Get a specific date for events. Overrides start and end dates.",
             default=None,
         )
-        parser.add_argument(
-            "-i",
-            "--importance",
-            action="store",
-            dest="importance",
-            choices=investingcom_model.IMPORTANCES,
-            help="Event importance classified as high, medium, low or all.",
-        )
-        parser.add_argument(
-            "--categories",
-            action="store",
-            dest="category",
-            choices=investingcom_model.CATEGORIES,
-            default=None,
-            help="[INVESTING source only] Event category.",
-        )
         ns_parser = self.parse_known_args_and_warn(
             parser,
             other_args,
@@ -1098,6 +1137,20 @@ class EconomyController(BaseController):
         )
 
         if ns_parser:
+            if ns_parser.names:
+                for name in nasdaq_model.get_country_names():
+                    console.print(name)
+                return
+
+            if ns_parser.names:
+                for name in nasdaq_model.get_country_names():
+                    console.print(name)
+                return
+
+            if ns_parser.names:
+                for name in nasdaq_model.get_country_names():
+                    console.print(name)
+                return
 
             if ns_parser.start_date:
                 start_date = ns_parser.start_date.strftime("%Y-%m-%d")
@@ -1111,24 +1164,24 @@ class EconomyController(BaseController):
 
             # TODO: Add `Investing` to sources again when `investpy` is fixed
 
-            countries = (
-                ns_parser.country.replace("_", " ").title().split(",")
-                if ns_parser.country
-                else []
-            )
-
             if ns_parser.spec_date:
                 start_date = ns_parser.spec_date.strftime("%Y-%m-%d")
                 end_date = ns_parser.spec_date.strftime("%Y-%m-%d")
 
             else:
                 start_date, end_date = sorted([start_date, end_date])
+
+            countries = list_from_str(ns_parser.countries)
+
             nasdaq_view.display_economic_calendar(
-                country=countries,
+                countries=countries,
                 start_date=start_date,
                 end_date=end_date,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1326,6 +1379,9 @@ class EconomyController(BaseController):
                         dataset_yaxis_1=dataset_yaxis1,
                         dataset_yaxis_2=dataset_yaxis2,
                         export=ns_parser.export,
+                        sheet_name=" ".join(ns_parser.sheet_name)
+                        if ns_parser.sheet_name
+                        else None,
                     )
 
     @log_start_end(log=logger)
@@ -1351,6 +1407,9 @@ class EconomyController(BaseController):
             alphavantage_view.realtime_performance_sector(
                 raw=ns_parser.raw,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1411,6 +1470,9 @@ class EconomyController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1469,6 +1531,9 @@ class EconomyController(BaseController):
                 sortby=ns_parser.sortby,
                 ascend=ns_parser.reverse,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -1486,7 +1551,13 @@ class EconomyController(BaseController):
             parser, other_args, export_allowed=EXPORT_ONLY_RAW_DATA_ALLOWED, limit=20
         )
         if ns_parser:
-            commodity_view.display_debt(export=ns_parser.export, limit=ns_parser.limit)
+            commodity_view.display_debt(
+                export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+                limit=ns_parser.limit,
+            )
 
     @log_start_end(log=logger)
     def call_spectrum(self, other_args: List[str]):
@@ -1562,7 +1633,7 @@ class EconomyController(BaseController):
             self.stored_datasets = economy_helpers.update_stored_datasets_string(
                 self.DATASETS
             )
-        console.print()
+            self.update_runtime_choices()
 
     @log_start_end(log=logger)
     def call_qa(self, _):
