@@ -13,7 +13,12 @@ logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
-def show_top_mover(sort_type: str = "gainers", limit: int = 10, export: str = ""):
+def show_top_mover(
+    sort_type: str = "gainers",
+    limit: int = 10,
+    export: str = "",
+    sheet_name: str = None,
+):
     """
     Show top ETF movers from wsj.com
 
@@ -23,6 +28,8 @@ def show_top_mover(sort_type: str = "gainers", limit: int = 10, export: str = ""
         What to show. Either Gainers, Decliners or Activity
     limit: int
         Number of etfs to show
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Format to export data
     """
@@ -43,4 +50,5 @@ def show_top_mover(sort_type: str = "gainers", limit: int = 10, export: str = ""
         os.path.dirname(os.path.abspath(__file__)),
         sort_type,
         data,
+        sheet_name,
     )
