@@ -1,4 +1,4 @@
-# pylint: disable=too-many-arguments
+# pylint: disable=too-many-arguments,too-many-lines
 import os
 import argparse
 from typing import Any, Union, Optional, List, Dict, Tuple
@@ -96,7 +96,6 @@ def plot_data_predictions(
         label="Real data",
     )
     for i in range(len(y_valid) - 1):
-
         if scaler:
             y_pred = scaler.inverse_transform(preds[i].reshape(-1, 1)).ravel()
             y_act = scaler.inverse_transform(y_valid[i].reshape(-1, 1)).ravel()
@@ -403,7 +402,6 @@ def past_covs(
     is_scaler: bool = True,
 ):
     if past_covariates is not None:
-
         target_covariates_names = past_covariates.split(",")
 
         # create first covariate to then stack
@@ -454,7 +452,7 @@ def get_pl_kwargs(
     pl_trainer_kwargs = {
         "callbacks": [my_stopper],
         "accelerator": accelerator,
-        "logger": False,
+        # "logger": False,
         # "enable_progress_bar": False,
         "enable_model_summary": False,
     }
@@ -475,6 +473,7 @@ def plot_forecast(
     precision: Optional[int] = None,
     probabilistic: bool = False,
     export: str = "",
+    sheet_name: str = None,
     low_quantile: float = None,
     high_quantile: float = None,
     forecast_only: bool = False,
@@ -538,7 +537,12 @@ def plot_forecast(
     print_pretty_prediction(numeric_forecast, data[target_col].iloc[-1])
 
     # user wants to export plot
-    export_data(export, os.path.dirname(os.path.abspath(__file__)), name)
+    export_data(
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        name,
+        sheet_name,
+    )
 
     # user wants to export only raw predictions
     if export_pred_raw:
@@ -561,12 +565,14 @@ def plot_forecast(
             os.path.dirname(os.path.abspath(__file__)),
             name + "_predictions",
             numeric_forecast,
+            sheet_name,
         )
 
 
 def plot_explainability(
     model: type[GlobalForecastingModel],
     explainability_raw=False,
+    sheet_name: str = None,
     external_axes: Optional[List[plt.axes]] = None,
 ):
     """
@@ -601,6 +607,7 @@ def plot_explainability(
             os.path.dirname(os.path.abspath(__file__)),
             "explainability_raw",
             raw_df,
+            sheet_name,
         )
 
     ax.yaxis.set_label_position("left")
@@ -721,7 +728,7 @@ def get_prediction(
     if model_name not in ["Regression", "Logistic Regression"]:
         # need to create a new pytorch trainer for historical backtesting to remove progress bar
         best_model.trainer = None
-        best_model.trainer_params["enable_progress_bar"] = False
+        # best_model.trainer_params["enable_progress_bar"] = True
 
     # Historical backtest if with covariates
     if past_covariates is not None:
@@ -980,3 +987,13 @@ def check_dates(s: pd.Series) -> bool:
         except AttributeError:
             return False
     return True
+
+
+def print_tensorboard_logs(model_save_name: str, user_directory: str):
+    console.print()
+    tensorboard_logs_dir = os.path.join(user_directory, model_save_name, "logs")
+    console.print(
+        "This model supports Tensorboard logs. To view, open a new terminal windown and run:"
+    )
+    console.print("tensorboard --logdir=" + tensorboard_logs_dir)
+    console.print()
