@@ -98,6 +98,7 @@ def load(
     resolution: str = "d",
     interval: str = "1day",
     start_date: Optional[str] = None,
+    end_date: Optional[str] = None,
     source: str = "YahooFinance",
     verbose: bool = False,
 ) -> pd.DataFrame:
@@ -115,6 +116,8 @@ def load(
         What interval to get data for, by default "1day"
     start_date : Optional[str], optional
         When to begin loading in data, by default last_year.strftime("%Y-%m-%d")
+    end_date : Optional[str], optional
+        When to end loading in data, by default None
     source : str, optional
         Where to get data from, by default "YahooFinance"
     verbose : bool, optional
@@ -124,10 +127,17 @@ def load(
     -------
     pd.DataFrame
         The loaded data
+
+    Examples
+    --------
+    >>> from openbb_terminal.sdk import openbb
+    >>> openbb.forex.load(from_symbol="EUR", to_symbol="USD", start_date="2020-11-30", end_date="2022-12-01")
     """
 
     if start_date is None:
         start_date = (datetime.now() - timedelta(days=365)).strftime("%Y-%m-%d")
+    if end_date is None:
+        end_date = datetime.now().strftime("%Y-%m-%d")
 
     if source in ["YahooFinance", "AlphaVantage"]:
         interval_map = INTERVAL_MAPS[source]
@@ -159,6 +169,7 @@ def load(
                 resolution=resolution,
                 interval=clean_interval,
                 start_date=start_date,
+                end_date=end_date,
             )
             df.index.name = "date"
             return df
@@ -167,6 +178,7 @@ def load(
             df = yf.download(
                 f"{from_symbol}{to_symbol}=X",
                 start=datetime.strptime(start_date, "%Y-%m-%d"),
+                end=datetime.strptime(end_date, "%Y-%m-%d"),
                 interval=clean_interval,
                 progress=verbose,
             )
@@ -185,6 +197,7 @@ def load(
             multiplier=multiplier,
             timespan=timeframe,
             start_date=start_date,
+            end_date=end_date,
         )
         df.index.name = "date"
         return df
@@ -258,7 +271,9 @@ def display_candle(
         External axes (1 axis is expected in the list), by default None
     """
     # We check if there's Volume data to avoid errors and empty subplots
-    has_volume = bool(data["Volume"].sum() > 0)
+    has_volume = False
+    if "Volume" in data.columns:
+        has_volume = bool(data["Volume"].sum() > 0)
 
     if add_trend:
         if (data.index[1] - data.index[0]).total_seconds() >= 86400:
