@@ -13,7 +13,7 @@ logger = logging.getLogger(__name__)
 
 
 @log_start_end(log=logger)
-def display_keys(show: bool = False, export: str = ""):
+def display_keys(show: bool = False, export: str = "", sheet_name: str = None):
     """Display currently set API keys.
 
     Parameters
@@ -42,4 +42,5 @@ def display_keys(show: bool = False, export: str = ""):
         os.path.dirname(os.path.abspath(__file__)),
         "mykeys",
         df,
+        sheet_name,
     )
