@@ -1,7 +1,7 @@
 """Parent Classes."""
 __docformat__ = "numpy"
 
-# pylint: disable=C0301,C0302,R0902,global-statement
+# pylint: disable=C0301,C0302,R0902,global-statement,too-many-boolean-expressions
 
 import argparse
 import difflib
@@ -33,9 +33,7 @@ from openbb_terminal.helper_funcs import (
     check_positive,
     export_data,
     get_flair,
-    load_json,
     parse_and_split_input,
-    parse_simple_args,
     prefill_form,
     screenshot,
     search_wikipedia,
@@ -92,7 +90,6 @@ class BaseController(metaclass=ABCMeta):
         "r",
         "reset",
         "support",
-        "glossary",
         "wiki",
         "record",
         "stop",
@@ -103,6 +100,7 @@ class BaseController(metaclass=ABCMeta):
     CHOICES_MENUS: List[str] = []
     SUPPORT_CHOICES: dict = {}
     ABOUT_CHOICES: dict = {}
+    NEWS_CHOICES: dict = {}
     COMMAND_SEPARATOR = "/"
     KEYS_MENU = "keys" + COMMAND_SEPARATOR
     TRY_RELOAD = False
@@ -163,6 +161,7 @@ class BaseController(metaclass=ABCMeta):
             c for c in self.controller_choices if c not in self.CHOICES_COMMON
         ]
 
+        # Add in support options
         support_choices: dict = {c: {} for c in self.controller_choices}
 
         support_choices = {c: None for c in (["generic"] + self.support_commands)}
@@ -177,6 +176,10 @@ class BaseController(metaclass=ABCMeta):
 
         self.SUPPORT_CHOICES = support_choices
 
+        # Add in news options
+        news_choices = ["--term", "-t", "--sources", "-s", "--help", "-h"]
+        self.NEWS_CHOICES = {c: None for c in news_choices}
+
     def check_path(self) -> None:
         """Check if command path is valid."""
         path = self.PATH
@@ -325,7 +328,6 @@ class BaseController(metaclass=ABCMeta):
 
         # Navigation slash is being used first split commands
         elif len(actions) > 1:
-
             # Absolute path is specified
             if not actions[0]:
                 actions[0] = "home"
@@ -411,7 +413,7 @@ class BaseController(metaclass=ABCMeta):
             dest="command",
             default=None,
             help="Obtain documentation on the given command or menu",
-            choices=self.CHOICES_COMMANDS + self.CHOICES_MENUS,
+            choices=self.CHOICES_COMMANDS + self.CHOICES_MENUS + self.CHOICES_COMMON,
         )
 
         if other_args and "-" not in other_args[0][0]:
@@ -470,7 +472,7 @@ class BaseController(metaclass=ABCMeta):
             prog="resources",
             description="Display available markdown resources.",
         )
-        ns_parser = parse_simple_args(parser, other_args)
+        ns_parser = self.parse_simple_args(parser, other_args)
 
         if ns_parser:
             if os.path.isfile(self.FILE_PATH):
@@ -531,7 +533,7 @@ class BaseController(metaclass=ABCMeta):
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-c")
 
-        ns_parser = parse_simple_args(parser, other_args)
+        ns_parser = self.parse_simple_args(parser, other_args)
 
         if ns_parser:
             prefill_form(
@@ -542,42 +544,6 @@ class BaseController(metaclass=ABCMeta):
                 path=self.PATH,
             )
 
-    @log_start_end(log=logger)
-    def call_glossary(self, other_args: List[str]) -> None:
-        """Process glossary command."""
-        parser = argparse.ArgumentParser(
-            add_help=False,
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
-            prog="support",
-            description="Submit your support request",
-        )
-        parser.add_argument(
-            "-w",
-            "--word",
-            action="store",
-            dest="word",
-            type=str,
-            required="-h" not in other_args,
-            help="Word that you want defined",
-        )
-        if other_args and "-" not in other_args[0][0]:
-            other_args.insert(0, "-w")
-
-        ns_parser = parse_simple_args(parser, other_args)
-
-        glossary_file = os.path.join(os.path.dirname(__file__), "glossary.json")
-        glossary_dict = load_json(glossary_file)
-
-        if ns_parser:
-            word = glossary_dict.get(ns_parser.word, "")
-            word = word.lower()
-            word = word.replace("--", "")
-            word = word.replace("-", " ")
-            if word:
-                console.print(word + "\n")
-            else:
-                console.print("Word is not in the glossary.\n")
-
     @log_start_end(log=logger)
     def call_wiki(self, other_args: List[str]) -> None:
         """Process wiki command."""
@@ -600,7 +566,7 @@ class BaseController(metaclass=ABCMeta):
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-e")
 
-        ns_parser = parse_simple_args(parser, other_args)
+        ns_parser = self.parse_simple_args(parser, other_args)
 
         if ns_parser:
             if ns_parser.expression:
@@ -627,7 +593,7 @@ class BaseController(metaclass=ABCMeta):
         )
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-r")
-        ns_parser = parse_simple_args(parser, other_args)
+        ns_parser = self.parse_simple_args(parser, other_args)
 
         if ns_parser:
             global SESSION_RECORDED_NAME
@@ -690,13 +656,56 @@ class BaseController(metaclass=ABCMeta):
             "Default target is plot if there is one open, otherwise it's terminal window. "
             " In case the user wants the terminal window, it can be forced with '-t` or '--terminal' flag passed.",
         )
-        ns_parser = parse_simple_args(parser, other_args)
+        ns_parser = self.parse_simple_args(parser, other_args)
 
         if ns_parser:
             screenshot()
 
+    @staticmethod
+    def parse_simple_args(parser: argparse.ArgumentParser, other_args: List[str]):
+        """Parse list of arguments into the supplied parser.
+
+        Parameters
+        ----------
+        parser: argparse.ArgumentParser
+            Parser with predefined arguments
+        other_args: List[str]
+            List of arguments to parse
+
+        Returns
+        -------
+        ns_parser:
+            Namespace with parsed arguments
+        """
+        parser.add_argument(
+            "-h", "--help", action="store_true", help="show this help message"
+        )
+
+        if obbff.USE_CLEAR_AFTER_CMD:
+            system_clear()
+
+        try:
+            (ns_parser, l_unknown_args) = parser.parse_known_args(other_args)
+        except SystemExit:
+            # In case the command has required argument that isn't specified
+            console.print("\n")
+            return None
+
+        if ns_parser.help:
+            txt_help = parser.format_help()
+            console.print(f"[help]{txt_help}[/help]")
+            return None
+
+        if l_unknown_args:
+            console.print(
+                f"The following args couldn't be interpreted: {l_unknown_args}\n"
+            )
+
+        return ns_parser
+
+    @classmethod
     def parse_known_args_and_warn(
-        self,
+        cls,
         parser: argparse.ArgumentParser,
         other_args: List[str],
         export_allowed: int = NO_EXPORT,
@@ -747,9 +756,21 @@ class BaseController(metaclass=ABCMeta):
                 type=check_file_type_saved(choices_export),
                 dest="export",
                 help=help_export,
-                choices=choices_export,
             )
 
+            # If excel is an option, add the sheet name
+            if export_allowed in [
+                EXPORT_ONLY_RAW_DATA_ALLOWED,
+                EXPORT_BOTH_RAW_DATA_AND_FIGURES,
+            ]:
+                parser.add_argument(
+                    "--sheet-name",
+                    dest="sheet_name",
+                    default=None,
+                    nargs="+",
+                    help="Name of excel sheet to save data to. Only valid for .xlsx files.",
+                )
+
         if raw:
             parser.add_argument(
                 "--raw",
@@ -767,7 +788,7 @@ class BaseController(metaclass=ABCMeta):
                 help="Number of entries to show in data.",
                 type=check_positive,
             )
-        sources = get_ordered_list_sources(f"{self.PATH}{parser.prog}")
+        sources = get_ordered_list_sources(f"{cls.PATH}{parser.prog}")
         # Allow to change source if there is more than one
         if len(sources) > 1:
             parser.add_argument(
@@ -957,7 +978,7 @@ class StockBaseController(BaseController, metaclass=ABCMeta):
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
             prog="load",
             description="Load stock ticker to perform analysis on. When the data source"
-            + " is syf', an Indian ticker can be"
+            + " is yf, an Indian ticker can be"
             + " loaded by using '.NS' at the end, e.g. 'SBIN.NS'. See available market in"
             + " https://help.yahoo.com/kb/exchanges-data-providers-yahoo-finance-sln2310.html.",
         )
@@ -1036,7 +1057,20 @@ class StockBaseController(BaseController, metaclass=ABCMeta):
             type=str,
             default="ytd",
         )
-
+        parser.add_argument(
+            "--exchange",
+            dest="exchange",
+            action="store_true",
+            default=False,
+            help="Show exchange information.",
+        )
+        parser.add_argument(
+            "--performance",
+            dest="performance",
+            action="store_true",
+            default=False,
+            help="Show performance information.",
+        )
         if other_args and "-" not in other_args[0][0]:
             other_args.insert(0, "-t")
 
@@ -1083,19 +1117,26 @@ class StockBaseController(BaseController, metaclass=ABCMeta):
                 )
                 if df_stock_candidate.empty:
                     return
-            if not df_stock_candidate.empty:
+            is_df = isinstance(df_stock_candidate, pd.DataFrame)
+            if not (
+                (is_df and df_stock_candidate.empty)
+                or (not is_df and not df_stock_candidate)
+            ):
                 self.stock = df_stock_candidate
-                self.add_info = stocks_helper.additional_info_about_ticker(
-                    ns_parser.ticker
-                )
-                console.print(self.add_info)
+                if ns_parser.exchange:
+                    self.add_info = stocks_helper.additional_info_about_ticker(
+                        ns_parser.ticker
+                    )
+                    console.print(self.add_info)
                 if (
                     ns_parser.interval == 1440
                     and not ns_parser.weekly
                     and not ns_parser.monthly
                     and ns_parser.filepath is None
                     and self.PATH == "/stocks/"
+                    and ns_parser.performance
                 ):
+                    console.print()
                     stocks_helper.show_quick_performance(self.stock, ns_parser.ticker)
                 if "." in ns_parser.ticker:
                     self.ticker, self.suffix = ns_parser.ticker.upper().split(".")
@@ -1126,8 +1167,11 @@ class StockBaseController(BaseController, metaclass=ABCMeta):
                 export_data(
                     ns_parser.export,
                     os.path.dirname(os.path.abspath(__file__)),
-                    "load",
+                    f"load_{self.ticker}",
                     self.stock.copy(),
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
 
 
@@ -1257,4 +1301,7 @@ class CryptoBaseController(BaseController, metaclass=ABCMeta):
                     os.path.dirname(os.path.abspath(__file__)),
                     "load",
                     self.current_df.copy(),
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
