@@ -104,6 +104,7 @@ def display_transactions(
     show_index=False,
     limit: int = 10,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display portfolio transactions
 
@@ -136,6 +137,7 @@ def display_transactions(
             os.path.dirname(os.path.abspath(__file__)),
             "transactions",
             df.set_index("Date"),
+            sheet_name,
         )
 
 
@@ -345,10 +347,9 @@ def display_performance_vs_benchmark(
 
     Parameters
     ----------
-    portfolio_trades: pd.DataFrame
-        Object containing trades made within the portfolio.
-    benchmark_trades: pd.DataFrame
-        Object containing trades made within the benchmark.
+    portfolio_engine: PortfolioEngine
+        PortfolioEngine class instance, this will hold transactions and perform calculations.
+        Use `portfolio.load` to create a PortfolioEngine.
     show_all_trades: bool
         Whether to also show all trades made and their performance (default is False)
     """
@@ -378,6 +379,7 @@ def display_yearly_returns(
     window: str = "all",
     raw: bool = False,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[plt.Axes] = None,
 ):
     """Display yearly returns
@@ -450,6 +452,7 @@ def display_yearly_returns(
         os.path.dirname(os.path.abspath(__file__)),
         "yret",
         df,
+        sheet_name,
     )
 
 
@@ -460,6 +463,7 @@ def display_monthly_returns(
     raw: bool = False,
     show_vals: bool = False,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[plt.Axes] = None,
 ):
     """Display monthly returns
@@ -550,6 +554,7 @@ def display_monthly_returns(
         os.path.dirname(os.path.abspath(__file__)),
         "mret",
         portfolio_returns,
+        sheet_name,
     )
 
 
@@ -560,6 +565,7 @@ def display_daily_returns(
     raw: bool = False,
     limit: int = 10,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[plt.Axes] = None,
 ):
     """Display daily returns
@@ -602,12 +608,19 @@ def display_daily_returns(
                 return
             ax = external_axes
 
+        clrs_portfolio = [
+            theme.down_color if (x < 0) else theme.up_color for x in df["portfolio"]
+        ]
+        clrs_benchmark = [
+            theme.down_color if (x < 0) else theme.up_color for x in df["benchmark"]
+        ]
+
         ax[0].set_title(f"Portfolio in period {window}")
-        ax[0].plot(df.index, df["portfolio"], label="Portfolio")
+        ax[0].bar(df.index, df["portfolio"], label="Portfolio", color=clrs_portfolio)
         ax[0].set_ylabel("Returns [%]")
         theme.style_primary_axis(ax[0])
         ax[1].set_title(f"Benchmark in period {window}")
-        ax[1].plot(df.index, df["benchmark"], label="Benchmark")
+        ax[1].bar(df.index, df["benchmark"], label="Benchmark", color=clrs_benchmark)
         ax[1].set_ylabel("Returns [%]")
         theme.style_primary_axis(ax[1])
 
@@ -619,6 +632,7 @@ def display_daily_returns(
         os.path.dirname(os.path.abspath(__file__)),
         "dret",
         df,
+        sheet_name,
     )
 
 
@@ -628,6 +642,7 @@ def display_distribution_returns(
     window: str = "all",
     raw: bool = False,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[plt.Axes] = None,
 ):
     """Display daily returns
@@ -706,6 +721,7 @@ def display_distribution_returns(
         os.path.dirname(os.path.abspath(__file__)),
         "distr",
         stats,
+        sheet_name,
     )
 
 
@@ -716,6 +732,7 @@ def display_holdings_value(
     raw: bool = False,
     limit: int = 10,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[plt.Axes] = None,
 ):
     """Display holdings of assets (absolute value)
@@ -731,6 +748,8 @@ def display_holdings_value(
         To display raw data
     limit : int
         Number of past market days to display holdings
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Format to export plot
     external_axes: plt.Axes
@@ -785,6 +804,7 @@ def display_holdings_value(
         os.path.dirname(os.path.abspath(__file__)),
         "holdv",
         all_holdings,
+        sheet_name,
     )
 
 
@@ -795,6 +815,7 @@ def display_holdings_percentage(
     raw: bool = False,
     limit: int = 10,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[plt.Axes] = None,
 ):
     """Display holdings of assets (in percentage)
@@ -810,6 +831,8 @@ def display_holdings_percentage(
         To display raw data
     limit : int
         Number of past market days to display holdings
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Format to export plot
     external_axes: plt.Axes
@@ -869,6 +892,7 @@ def display_holdings_percentage(
         os.path.dirname(os.path.abspath(__file__)),
         "holdp",
         all_holdings,
+        sheet_name,
     )
 
 
@@ -877,6 +901,7 @@ def display_rolling_volatility(
     portfolio_engine: PortfolioEngine,
     window: str = "1y",
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Display rolling volatility
@@ -887,6 +912,8 @@ def display_rolling_volatility(
         PortfolioEngine object
     interval: str
         interval for window to consider
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export to file
     external_axes: Optional[List[plt.Axes]]
@@ -925,6 +952,7 @@ def display_rolling_volatility(
         os.path.dirname(os.path.abspath(__file__)),
         metric,
         df_portfolio.to_frame().join(df_benchmark),
+        sheet_name,
     )
 
 
@@ -934,6 +962,7 @@ def display_rolling_sharpe(
     risk_free_rate: float = 0,
     window: str = "1y",
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Display rolling sharpe
@@ -946,6 +975,8 @@ def display_rolling_sharpe(
         Value to use for risk free rate in sharpe/other calculations
     window: str
         interval for window to consider
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export to file
     external_axes: Optional[List[plt.Axes]]
@@ -984,6 +1015,7 @@ def display_rolling_sharpe(
         os.path.dirname(os.path.abspath(__file__)),
         metric,
         df_portfolio.to_frame().join(df_benchmark),
+        sheet_name,
     )
 
 
@@ -993,6 +1025,7 @@ def display_rolling_sortino(
     risk_free_rate: float = 0,
     window: str = "1y",
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Display rolling sortino
@@ -1005,6 +1038,8 @@ def display_rolling_sortino(
         Value to use for risk free rate in sharpe/other calculations
     window: str
         interval for window to consider
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export to file
     external_axes: Optional[List[plt.Axes]]
@@ -1043,6 +1078,7 @@ def display_rolling_sortino(
         os.path.dirname(os.path.abspath(__file__)),
         metric,
         df_portfolio.to_frame().join(df_benchmark),
+        sheet_name,
     )
 
 
@@ -1051,6 +1087,7 @@ def display_rolling_beta(
     portfolio_engine: PortfolioEngine,
     window: str = "1y",
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Display rolling beta
@@ -1062,6 +1099,8 @@ def display_rolling_beta(
     window: str
         interval for window to consider
         Possible options: mtd, qtd, ytd, 1d, 5d, 10d, 1m, 3m, 6m, 1y, 3y, 5y, 10y.
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export to file
     external_axes: Optional[List[plt.Axes]]
@@ -1104,6 +1143,7 @@ def display_rolling_beta(
         os.path.dirname(os.path.abspath(__file__)),
         metric,
         rolling_beta,
+        sheet_name,
     )
 
 
@@ -1111,6 +1151,7 @@ def display_rolling_beta(
 def display_maximum_drawdown(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
     external_axes: Optional[List[plt.Axes]] = None,
 ):
     """Display maximum drawdown curve
@@ -1119,6 +1160,8 @@ def display_maximum_drawdown(
     ----------
     portfolio : PortfolioEngine
         PortfolioEngine object
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Format to export data
     external_axes: plt.Axes
@@ -1149,6 +1192,7 @@ def display_maximum_drawdown(
         os.path.dirname(os.path.abspath(__file__)),
         "maxdd",
         drawdown,
+        sheet_name,
     )
 
 
@@ -1156,6 +1200,7 @@ def display_maximum_drawdown(
 def display_rsquare(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display R-square
 
@@ -1182,6 +1227,7 @@ def display_rsquare(
         os.path.dirname(os.path.abspath(__file__)),
         "rsquare",
         df,
+        sheet_name,
     )
 
 
@@ -1189,6 +1235,7 @@ def display_rsquare(
 def display_skewness(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display skewness
 
@@ -1213,6 +1260,7 @@ def display_skewness(
         export,
         os.path.dirname(os.path.abspath(__file__)),
         "skew",
+        sheet_name,
     )
 
 
@@ -1220,6 +1268,7 @@ def display_skewness(
 def display_kurtosis(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display kurtosis
 
@@ -1244,6 +1293,7 @@ def display_kurtosis(
         export,
         os.path.dirname(os.path.abspath(__file__)),
         "kurt",
+        sheet_name,
     )
 
 
@@ -1252,6 +1302,7 @@ def display_stats(
     portfolio_engine: PortfolioEngine,
     window: str = "all",
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display stats
 
@@ -1278,6 +1329,7 @@ def display_stats(
         export,
         os.path.dirname(os.path.abspath(__file__)),
         "stats",
+        sheet_name,
     )
 
 
@@ -1285,6 +1337,7 @@ def display_stats(
 def display_volatility(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display volatility for multiple intervals
 
@@ -1305,7 +1358,11 @@ def display_volatility(
         floatfmt=".2%",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_volatility", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_volatility",
+        df,
+        sheet_name,
     )
 
 
@@ -1314,6 +1371,7 @@ def display_sharpe_ratio(
     portfolio_engine: PortfolioEngine,
     risk_free_rate: float = 0,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display sharpe ratio for multiple intervals
 
@@ -1340,6 +1398,7 @@ def display_sharpe_ratio(
         os.path.dirname(os.path.abspath(__file__)),
         "metric_sharpe",
         df,
+        sheet_name,
     )
 
 
@@ -1348,6 +1407,7 @@ def display_sortino_ratio(
     portfolio_engine: PortfolioEngine,
     risk_free_rate: float = 0,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display sortino ratio for multiple intervals
 
@@ -1374,6 +1434,7 @@ def display_sortino_ratio(
         os.path.dirname(os.path.abspath(__file__)),
         "metric_sortino",
         df,
+        sheet_name,
     )
 
 
@@ -1381,6 +1442,7 @@ def display_sortino_ratio(
 def display_maximum_drawdown_ratio(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display maximum drawdown for multiple intervals
 
@@ -1401,7 +1463,11 @@ def display_maximum_drawdown_ratio(
         floatfmt=".2f",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_maxdrawdown", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_maxdrawdown",
+        df,
+        sheet_name,
     )
 
 
@@ -1409,6 +1475,7 @@ def display_maximum_drawdown_ratio(
 def display_gaintopain_ratio(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display gain-to-pain ratio for multiple intervals
 
@@ -1432,6 +1499,7 @@ def display_gaintopain_ratio(
         os.path.dirname(os.path.abspath(__file__)),
         "metric_gaintopain_ratio",
         df,
+        sheet_name,
     )
 
 
@@ -1439,6 +1507,7 @@ def display_gaintopain_ratio(
 def display_tracking_error(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display tracking error for multiple intervals
 
@@ -1459,7 +1528,11 @@ def display_tracking_error(
         floatfmt=".2%",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_tracking_error", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_tracking_error",
+        df,
+        sheet_name,
     )
 
 
@@ -1467,6 +1540,7 @@ def display_tracking_error(
 def display_information_ratio(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display information ratio for multiple intervals
 
@@ -1490,6 +1564,7 @@ def display_information_ratio(
         os.path.dirname(os.path.abspath(__file__)),
         "metric_information_ratio",
         df,
+        sheet_name,
     )
 
 
@@ -1497,6 +1572,7 @@ def display_information_ratio(
 def display_tail_ratio(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display tail ratio for multiple intervals
 
@@ -1519,7 +1595,11 @@ def display_tail_ratio(
         floatfmt=".2f",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_tail_ratio", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_tail_ratio",
+        df,
+        sheet_name,
     )
 
 
@@ -1527,6 +1607,7 @@ def display_tail_ratio(
 def display_common_sense_ratio(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display common sense ratio for multiple intervals
 
@@ -1550,6 +1631,7 @@ def display_common_sense_ratio(
         os.path.dirname(os.path.abspath(__file__)),
         "metric_common_sense_ratio",
         df,
+        sheet_name,
     )
 
 
@@ -1558,6 +1640,7 @@ def display_jensens_alpha(
     portfolio_engine: PortfolioEngine,
     risk_free_rate: float = 0,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display jensens alpha for multiple intervals
 
@@ -1580,7 +1663,11 @@ def display_jensens_alpha(
         floatfmt=".2%",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_jensens_alpha", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_jensens_alpha",
+        df,
+        sheet_name,
     )
 
 
@@ -1588,6 +1675,7 @@ def display_jensens_alpha(
 def display_calmar_ratio(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display calmar ratio for multiple intervals
 
@@ -1608,7 +1696,11 @@ def display_calmar_ratio(
         floatfmt=".2f",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_calmar_ratio", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_calmar_ratio",
+        df,
+        sheet_name,
     )
 
 
@@ -1616,6 +1708,7 @@ def display_calmar_ratio(
 def display_kelly_criterion(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display kelly criterion for multiple intervals
 
@@ -1635,13 +1728,18 @@ def display_kelly_criterion(
         floatfmt=".2%",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_kelly_criterion", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_kelly_criterion",
+        df,
+        sheet_name,
     )
 
 
 def display_payoff_ratio(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display payoff ratio for multiple intervals
 
@@ -1662,13 +1760,18 @@ def display_payoff_ratio(
         floatfmt=".2f",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_payoff_ratio", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_payoff_ratio",
+        df,
+        sheet_name,
     )
 
 
 def display_profit_factor(
     portfolio_engine: PortfolioEngine,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display profit factor for multiple intervals
 
@@ -1689,7 +1792,11 @@ def display_profit_factor(
         floatfmt=".2f",
     )
     export_data(
-        export, os.path.dirname(os.path.abspath(__file__)), "metric_profit_factor", df
+        export,
+        os.path.dirname(os.path.abspath(__file__)),
+        "metric_profit_factor",
+        df,
+        sheet_name,
     )
 
 
@@ -1699,6 +1806,7 @@ def display_summary(
     window: str = "all",
     risk_free_rate: float = 0,
     export: str = "",
+    sheet_name: str = None,
 ):
     """Display summary portfolio and benchmark returns
 
@@ -1727,6 +1835,7 @@ def display_summary(
         os.path.dirname(os.path.abspath(__file__)),
         "summary",
         summary,
+        sheet_name,
     )
 
 
@@ -1756,7 +1865,7 @@ def display_var(
     """
 
     qa_view.display_var(
-        data=portfolio_engine.returns,
+        data=portfolio_engine.portfolio_returns,
         symbol="Portfolio",
         use_mean=use_mean,
         adjusted_var=adjusted_var,
@@ -1789,7 +1898,7 @@ def display_es(
     """
 
     qa_view.display_es(
-        data=portfolio_engine.returns,
+        data=portfolio_engine.portfolio_returns,
         symbol="Portfolio",
         use_mean=use_mean,
         distribution=distribution,
@@ -1818,7 +1927,7 @@ def display_omega(
     """
 
     qa_view.display_omega(
-        data=portfolio_engine.returns,
+        data=portfolio_engine.portfolio_returns,
         threshold_start=threshold_start,
         threshold_end=threshold_end,
     )
