@@ -19,7 +19,8 @@ from openbb_terminal.decorators import log_start_end
 from openbb_terminal.menu import session
 from openbb_terminal.parent_classes import BaseController
 from openbb_terminal.rich_config import console, MenuText
-from openbb_terminal.terminal_helper import is_packaged_application
+
+# from openbb_terminal.terminal_helper import is_packaged_application
 
 logger = logging.getLogger(__name__)
 
@@ -60,7 +61,6 @@ class ReportController(BaseController):
             )
 
         if session and obbff.USE_PROMPT_TOOLKIT:
-
             self.choices: dict = {c: {} for c in self.controller_choices}
             self.choices["run"] = {
                 "--file": {c: None for c in reports_model.USER_REPORTS},
@@ -69,7 +69,6 @@ class ReportController(BaseController):
                 "-p": "--parameters",
             }
             for report_name in self.REPORTS:
-
                 # Completer with limited user choices to avoid unforeseen problems
                 self.choices[report_name] = {}
                 for arg in self.PARAMETERS_DICT[report_name]:
@@ -99,7 +98,6 @@ class ReportController(BaseController):
         MAX_LEN_NAME = max(len(name) for name in self.REPORTS) + 2
         templates_string = ""
         for report_name in self.REPORTS:
-
             parameters_names = list(self.PARAMETERS_DICT[report_name].keys())
 
             if len(parameters_names) > 1 or not parameters_names:
@@ -144,14 +142,14 @@ class ReportController(BaseController):
 
     @log_start_end(log=logger)
     def call_forecast(self, other_args: List[str]):
-        if is_packaged_application():
-            console.print("This report is disabled for the installed version")
-            return
+        # if is_packaged_application():
+        #     console.print("This report is disabled for the installed version")
+        #     return
 
         try:
-            import darts  # pyright: reportMissingImports=false # noqa: F401, E501 #pylint: disable=import-outside-toplevel, unused-import
-            from darts import (  # pyright: reportMissingImports=false # noqa: F401, E501 #pylint: disable=import-outside-toplevel, unused-import
-                utils,
+            import darts  # pyright: reportMissingImports=false # noqa: F401, E501 # pylint: disable=C0415, W0611
+            from darts import (  # pyright: reportMissingImports=false, pylint: disable=C0415, W0611
+                utils,  # noqa: F401, E501
             )
 
             FORECASTING_TOOLKIT_ENABLED = True
@@ -178,10 +176,8 @@ class ReportController(BaseController):
         )
 
         if report_name in self.PARAMETERS_DICT:
-
             # Assign respective parameters as arguments
             for arg_name, arg_default in self.PARAMETERS_DICT[report_name].items():
-
                 choices = reports_model.get_arg_choices(report_name, arg_name)
 
                 getattr(parser, "add_argument")(
