@@ -3,8 +3,8 @@ from openbb_terminal.config_terminal import theme  # noqa: F401
 from openbb_terminal.helper_classes import TerminalStyle
 from openbb_terminal import helper_funcs as helper  # noqa: F401
 from openbb_terminal.reports import widget_helpers as widgets  # noqa: F401
-from openbb_terminal.cryptocurrency.due_diligence.pycoingecko_model import (  # noqa: F401
-    Coin,
+from openbb_terminal.cryptocurrency.due_diligence.pycoingecko_model import (
+    Coin,  # noqa: F401
 )
 
 from openbb_terminal.core.library.breadcrumb import Breadcrumb
