@@ -202,6 +202,9 @@ class DiscoveryController(BaseController):
                 ascend=ns_parser.reverse,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -256,6 +259,9 @@ class DiscoveryController(BaseController):
                 limit=ns_parser.limit,
                 start_date=ns_parser.start,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -312,6 +318,9 @@ class DiscoveryController(BaseController):
                 limit=ns_parser.limit,
                 end_date=ns_parser.end,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -341,6 +350,9 @@ class DiscoveryController(BaseController):
             yahoofinance_view.display_gainers(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -370,6 +382,9 @@ class DiscoveryController(BaseController):
             yahoofinance_view.display_losers(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -402,6 +417,9 @@ class DiscoveryController(BaseController):
             yahoofinance_view.display_ugs(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -432,6 +450,9 @@ class DiscoveryController(BaseController):
             yahoofinance_view.display_gtech(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -463,6 +484,9 @@ class DiscoveryController(BaseController):
             yahoofinance_view.display_active(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -494,6 +518,9 @@ class DiscoveryController(BaseController):
             yahoofinance_view.display_ulc(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -525,6 +552,9 @@ class DiscoveryController(BaseController):
             yahoofinance_view.display_asc(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -606,6 +636,9 @@ class DiscoveryController(BaseController):
                 sells_only=ns_parser.sells_only,
                 fund=ns_parser.fund,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -646,6 +679,9 @@ class DiscoveryController(BaseController):
                 num_pages=ns_parser.n_pages,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -694,6 +730,9 @@ class DiscoveryController(BaseController):
                 article_id=ns_parser.n_id,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -729,6 +768,9 @@ class DiscoveryController(BaseController):
             shortinterest_view.low_float(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -769,6 +811,9 @@ class DiscoveryController(BaseController):
                 news_type=ns_parser.s_type,
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -799,6 +844,9 @@ class DiscoveryController(BaseController):
             shortinterest_view.hot_penny_stocks(
                 limit=ns_parser.limit,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
                 source=ns_parser.source,
             )
 
@@ -857,4 +905,10 @@ class DiscoveryController(BaseController):
             parser, other_args, export_allowed=EXPORT_ONLY_RAW_DATA_ALLOWED
         )
         if ns_parser:
-            finviz_view.display_heatmap(ns_parser.timeframe, ns_parser.export)
+            finviz_view.display_heatmap(
+                ns_parser.timeframe,
+                ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
+            )
