@@ -7,7 +7,6 @@ from typing import List, Tuple
 
 import numpy as np
 import pandas as pd
-import requests
 from bs4 import BeautifulSoup
 
 from openbb_terminal.decorators import log_start_end
@@ -15,6 +14,7 @@ from openbb_terminal.helper_funcs import (
     lambda_clean_data_values_to_float,
     get_user_agent,
     lambda_int_or_round_float,
+    request,
 )
 
 logger = logging.getLogger(__name__)
@@ -69,7 +69,7 @@ def prepare_df_financials(
         period = "annual"
 
     text_soup_financials = BeautifulSoup(
-        requests.get(
+        request(
             financial_urls[statement][period].format(symbol),
             headers={"User-Agent": get_user_agent()},
         ).text,
@@ -161,7 +161,7 @@ def get_sean_seah_warnings(
         f"https://www.marketwatch.com/investing/stock/{symbol}/financials/income"
     )
     text_soup_financials = BeautifulSoup(
-        requests.get(url_financials, headers={"User-Agent": get_user_agent()}).text,
+        request(url_financials, headers={"User-Agent": get_user_agent()}).text,
         "lxml",
     )
 
@@ -209,7 +209,7 @@ def get_sean_seah_warnings(
         f"https://www.marketwatch.com/investing/stock/{symbol}/financials/balance-sheet"
     )
     text_soup_financials = BeautifulSoup(
-        requests.get(url_financials, headers={"User-Agent": get_user_agent()}).text,
+        request(url_financials, headers={"User-Agent": get_user_agent()}).text,
         "lxml",
     )
 
