@@ -108,7 +108,7 @@ class InsiderController(StockBaseController):
         mt.add_cmd("lip")
         mt.add_cmd("blip")
         mt.add_cmd("blop")
-        mt.add_cmd("bclp")
+        mt.add_cmd("blcp")
         mt.add_cmd("lis")
         mt.add_cmd("blis")
         mt.add_cmd("blos")
@@ -269,6 +269,9 @@ class InsiderController(StockBaseController):
                 limit=ns_parser.limit,
                 links=ns_parser.urls,
                 export=ns_parser.export,
+                sheet_name=" ".join(ns_parser.sheet_name)
+                if ns_parser.sheet_name
+                else None,
             )
 
     @log_start_end(log=logger)
@@ -310,6 +313,9 @@ class InsiderController(StockBaseController):
                     limit=ns_parser.limit,
                     links=ns_parser.urls,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("Please use `load <ticker>` before.\n")
@@ -904,6 +910,9 @@ class InsiderController(StockBaseController):
                     limit=ns_parser.limit,
                     raw=ns_parser.raw,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("No ticker loaded. First use `load {ticker}`\n")
@@ -939,6 +948,9 @@ class InsiderController(StockBaseController):
                     symbol=self.ticker,
                     limit=ns_parser.limit,
                     export=ns_parser.export,
+                    sheet_name=" ".join(ns_parser.sheet_name)
+                    if ns_parser.sheet_name
+                    else None,
                 )
             else:
                 console.print("No ticker loaded. First use `load {ticker}`\n")
