@@ -6,6 +6,7 @@ from typing import List
 import numpy as np
 import pandas as pd
 
+from openbb_terminal import rich_config
 from openbb_terminal.decorators import log_start_end
 from openbb_terminal.helper_funcs import (
     export_data,
@@ -18,7 +19,6 @@ from openbb_terminal.stocks.insider.openinsider_model import (
     get_open_insider_link,
     get_print_insider_data,
 )
-from openbb_terminal import rich_config
 
 logger = logging.getLogger(__name__)
 
@@ -105,7 +105,9 @@ def lambda_green_highlight(values):
 
 
 @log_start_end(log=logger)
-def print_insider_data(type_insider: str = "lcb", limit: int = 10, export: str = ""):
+def print_insider_data(
+    type_insider: str = "lcb", limit: int = 10, export: str = "", sheet_name: str = None
+):
     """Print insider data
 
     Parameters
@@ -114,6 +116,8 @@ def print_insider_data(type_insider: str = "lcb", limit: int = 10, export: str =
         Insider type of data. Available types can be accessed through get_insider_types().
     limit: int
         Limit of data rows to display
+    sheet_name: str
+        Optionally specify the name of the sheet the data is exported to.
     export: str
         Export data format
     """
@@ -128,7 +132,11 @@ def print_insider_data(type_insider: str = "lcb", limit: int = 10, export: str =
         )
 
         export_data(
-            export, os.path.dirname(os.path.abspath(__file__)), type_insider, df
+            export,
+            os.path.dirname(os.path.abspath(__file__)),
+            type_insider,
+            df,
+            sheet_name,
         )
 
         if df.shape[1] == 13:
@@ -146,6 +154,7 @@ def print_insider_filter(
     limit: int = 10,
     links: bool = False,
     export: str = "",
+    sheet_name: str = None,
 ) -> None:
     """Print insider filter based on loaded preset. [Source: OpenInsider]
 
@@ -245,4 +254,10 @@ def print_insider_filter(
         else:
             cmd = "filter"
 
-        export_data(export, os.path.dirname(os.path.abspath(__file__)), cmd, df_insider)
+        export_data(
+            export,
+            os.path.dirname(os.path.abspath(__file__)),
+            cmd,
+            df_insider,
+            sheet_name,
+        )
