@@ -6,10 +6,12 @@ from typing import List, Optional
 
 import pandas as pd
 import requests
+from tqdm import tqdm
 
 from openbb_terminal import config_terminal as cfg
 from openbb_terminal.decorators import check_api_key, log_start_end
 from openbb_terminal.rich_config import console
+from openbb_terminal.helper_funcs import request
 
 logger = logging.getLogger(__name__)
 
@@ -73,21 +75,20 @@ def get_historical_options(
     """
     if not chain_id:
         op_type = ["call", "put"][put]
-        chain = get_option_chains(symbol, expiry)
+        chain = get_option_chain(symbol, expiry)
+        chain = chain[chain["option_type"] == op_type]
 
         try:
-            symbol = chain[(chain.strike == strike) & (chain.option_type == op_type)][
-                "symbol"
-            ].values[0]
+            symbol = chain[(chain.strike == strike)]["symbol"].values[0]
         except IndexError:
-            error = f"Strike: {strike}, Option type: {op_type} not not found"
+            error = f"Strike: {strike}, Option type: {op_type} not found"
             logging.exception(error)
             console.print(f"{error}\n")
             return pd.DataFrame()
     else:
         symbol = chain_id
 
-    response = requests.get(
+    response = request(
         "https://sandbox.tradier.com/v1/markets/history",
         params={"symbol": {symbol}, "interval": "daily"},
         headers={
@@ -144,78 +145,11 @@ def get_full_option_chain(symbol: str) -> pd.DataFrame:
     expirations = option_expirations(symbol)
     options_dfs: pd.DataFrame = []
 
-    for expiry in expirations:
-        options_dfs.append(get_option_chains(symbol, expiry))
+    for expiry in tqdm(expirations, desc="Getting option chains"):
+        chain = get_option_chain(symbol, expiry)
+        options_dfs.append(chain)
 
-    options_df = pd.concat(options_dfs)
-
-    options_df.set_index(keys="symbol", inplace=True)
-
-    option_df_index = pd.Series(options_df.index).str.extractall(
-        r"^(?P<Ticker>\D*)(?P<Expiration>\d*)(?P<Type>\D*)(?P<Strike>\d*)"
-    )
-    option_df_index.reset_index(inplace=True)
-    option_df_index = pd.DataFrame(
-        option_df_index, columns=["Ticker", "Expiration", "Strike", "Type"]
-    )
-    option_df_index["Strike"] = options_df["strike"].values
-    option_df_index["Type"] = options_df["option_type"].values
-    option_df_index["Expiration"] = pd.DatetimeIndex(
-        data=option_df_index["Expiration"], yearfirst=True
-    ).strftime("%Y-%m-%d")
-    option_df_index["Type"] = pd.DataFrame(option_df_index["Type"]).replace(
-        to_replace=["put", "call"], value=["Put", "Call"]
-    )
-    options_df_columns = list(options_df.columns)
-    option_df_index.set_index(
-        keys=["Ticker", "Expiration", "Strike", "Type"], inplace=True
-    )
-    options_df = pd.DataFrame(
-        data=options_df.values, index=option_df_index.index, columns=options_df_columns
-    )
-
-    options_df.rename(
-        columns={
-            "bid": "Bid",
-            "ask": "Ask",
-            "strike": "Strike",
-            "bidsize": "Bid Size",
-            "asksize": "Ask Size",
-            "volume": "Volume",
-            "open_interest": "OI",
-            "delta": "Delta",
-            "gamma": "Gamma",
-            "theta": "Theta",
-            "vega": "Vega",
-            "ask_iv": "Ask IV",
-            "bid_iv": "Bid IV",
-            "mid_iv": "IV",
-        },
-        inplace=True,
-    )
-
-    options_columns = [
-        "Volume",
-        "OI",
-        "IV",
-        "Delta",
-        "Gamma",
-        "Theta",
-        "Vega",
-        "Bid Size",
-        "Bid",
-        "Ask",
-        "Ask Size",
-        "Bid IV",
-        "Ask IV",
-    ]
-
-    options = pd.DataFrame(options_df, columns=options_columns)
-    options = options.reset_index()
-    options.drop(labels=["Ticker"], inplace=True, axis=1)
-    options.rename(columns={"Expiration": "expiration"}, inplace=True)
-
-    return options
+    return pd.concat(options_dfs)
 
 
 @log_start_end(log=logger)
@@ -233,7 +167,7 @@ def option_expirations(symbol: str) -> List[str]:
     dates: List[str]
         List of of available expirations
     """
-    r = requests.get(
+    r = request(
         "https://sandbox.tradier.com/v1/markets/options/expirations",
         params={"symbol": symbol, "includeAllRoots": "true", "strikes": "false"},
         headers={
@@ -256,7 +190,7 @@ def option_expirations(symbol: str) -> List[str]:
 
 @log_start_end(log=logger)
 @check_api_key(["API_TRADIER_TOKEN"])
-def get_option_chains(symbol: str, expiry: str) -> pd.DataFrame:
+def get_option_chain(symbol: str, expiry: str) -> pd.DataFrame:
     """Display option chains [Source: Tradier]"
 
     Parameters
@@ -278,7 +212,7 @@ def get_option_chains(symbol: str, expiry: str) -> pd.DataFrame:
         "Accept": "application/json",
     }
 
-    response = requests.get(
+    response = request(
         "https://sandbox.tradier.com/v1/markets/options/chains",
         params=params,
         headers=headers,
@@ -288,12 +222,13 @@ def get_option_chains(symbol: str, expiry: str) -> pd.DataFrame:
         return pd.DataFrame()
 
     chains = process_chains(response)
+    chains["expiration"] = expiry
     return chains
 
 
 @log_start_end(log=logger)
 def process_chains(response: requests.models.Response) -> pd.DataFrame:
-    """Function to take in the requests.get and return a DataFrame
+    """Function to take in the request and return a DataFrame
 
     Parameters
     ----------
@@ -330,7 +265,7 @@ def process_chains(response: requests.models.Response) -> pd.DataFrame:
 
 @log_start_end(log=logger)
 @check_api_key(["API_TRADIER_TOKEN"])
-def last_price(symbol: str):
+def get_last_price(symbol: str):
     """Makes api request for last price
 
     Parameters
@@ -343,7 +278,7 @@ def last_price(symbol: str):
     float:
         Last price
     """
-    r = requests.get(
+    r = request(
         "https://sandbox.tradier.com/v1/markets/quotes",
         params={"symbols": symbol, "includeAllRoots": "true", "strikes": "false"},
         headers={
