@@ -13,7 +13,6 @@ from typing import List
 from packaging import version
 
 # IMPORTATION THIRDPARTY
-import requests
 import matplotlib.pyplot as plt
 
 # IMPORTATION INTERNAL
@@ -21,6 +20,7 @@ from openbb_terminal.config_terminal import LOGGING_APP_NAME, LOGGING_COMMIT_HAS
 from openbb_terminal import feature_flags as obbff
 from openbb_terminal import thought_of_the_day as thought
 from openbb_terminal.rich_config import console
+from openbb_terminal.helper_funcs import request
 
 # pylint: disable=too-many-statements,no-member,too-many-branches,C0302
 
@@ -137,6 +137,9 @@ def open_openbb_documentation(
     elif "sources" in path:
         path = "/guides/advanced/changing-sources"
         command = ""
+    elif "params" in path:
+        path = "/guides/intros/portfolio/po"
+        command = ""
     else:
         if arg_type == "command":  # user passed a command name
             path = f"/reference/{path}"
@@ -166,9 +169,20 @@ def open_openbb_documentation(
         elif "sources" in path:
             path = "/guides/advanced/changing-sources"
             command = ""
-        elif "exe" == command:
+        elif command in ["record", "stop", "exe"]:
             path = "/guides/advanced/scripts-and-routines"
             command = ""
+        elif command in [
+            "intro",
+            "about",
+            "support",
+            "survey",
+            "update",
+            "wiki",
+            "news",
+        ]:
+            path = ""
+            command = ""
         elif command in ["ta", "ba", "qa"]:
             path = f"/guides/intros/common/{command}"
             command = ""
@@ -239,9 +253,8 @@ def check_for_updates() -> None:
     # The commit has was commented out because the terminal was crashing due to git import for multiple users
     # ({str(git.Repo('.').head.commit)[:7]})
     try:
-        r = requests.get(
-            "https://api.github.com/repos/openbb-finance/openbbterminal/releases/latest",
-            timeout=1,
+        r = request(
+            "https://api.github.com/repos/openbb-finance/openbbterminal/releases/latest"
         )
     except Exception:
         r = None
@@ -252,7 +265,6 @@ def check_for_updates() -> None:
         current_version = version.parse(obbff.VERSION)
 
         if check_valid_versions(latest_version, current_version):
-
             if current_version == latest_version:
                 console.print("[green]You are using the latest stable version[/green]")
             else:
